# humba

[![Build Status](https://dev.azure.com/ddavis0485/humba/_apis/build/status/douglasdavis.humba?branchName=master)](https://dev.azure.com/ddavis0485/humba/_build/latest?definitionId=2&branchName=master)
[![Documentation Status](https://readthedocs.org/projects/humba/badge/?version=latest)](https://humba.readthedocs.io/en/latest/?badge=latest)

Histogramming accelerated with [numba](http://numba.pydata.org/).
